@@ -1,4 +1,5 @@
-#include "behaviortree_cpp/shared_library.h"
+#include "behaviortree_cpp_v3/utils/shared_library.h"
+#include "behaviortree_cpp_v3/exceptions.h"
 
 BT::SharedLibrary::SharedLibrary(const std::string& path, int flags)
 {
@@ -11,12 +12,12 @@ void* BT::SharedLibrary::getSymbol(const std::string& name)
     if (result)
         return result;
     else
-        throw std::runtime_error(name);
+        throw RuntimeError( "[SharedLibrary::getSymbol]: can't find symbol ", name );
 }
 
 bool BT::SharedLibrary::hasSymbol(const std::string& name)
 {
-    return findSymbol(name) != 0;
+    return findSymbol(name) != nullptr;
 }
 
 std::string BT::SharedLibrary::getOSName(const std::string& name)
